@@ -1,7 +1,5 @@
 # Copyright (c) Open-MMLab. All rights reserved.
-import torch.distributed as dist
-
-from ..dist_utils import get_dist_info
+from ..dist_utils import allreduce_params
 from .hook import HOOKS, Hook
 
 
@@ -20,9 +18,5 @@ class SyncBuffersHook(Hook):
 
     def after_epoch(self, runner):
         """All-reduce model buffers at the end of each epoch."""
-        _, world_size = get_dist_info()
-        if self.distributed and world_size > 1:
-            buffers = runner.model.buffers()
-            world_size = dist.get_world_size()
-            for tensor in buffers:
-                dist.all_reduce(tensor.div_(world_size))
+        if self.distributed:
+            allreduce_params(runner.model.buffers())
